ActivityData class

Data class for activity data

Constructors

ActivityData({required DateTime timestamp, required String activity})
const
ActivityData.fromMap(Map<String, dynamic> map)
factory

Properties

activity → String
final
hashCode → int
The hash code for this object.
no setterinherited
props → List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stringify → bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
timestamp → DateTime
final

Methods

copyWith({DateTime? timestamp, String? activity}) → ActivityData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited