MethodChannelCustomActivityRecognition class

The MethodChannel that will the implementation of CustomActivityRecognition.

Inheritance

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

activityStream() → Stream<ActivityData>
Stream of activity data
override
checkPermissionStatus() → Future<CustomActivityPermissionStatus>
Checks the current status of activity recognition permission
override
isActivityRecognitionAvailable() → Future<bool>
Checks if activity recognition is available
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestPermissions() → Future<bool>
Checks if activity recognition is available
override
startTracking({bool showNotification = true, bool useTransitionRecognition = true, bool useActivityRecognition = true, int detectionIntervalMillis = 10000, int confidenceThreshold = 50}) → Future<bool>
Starts tracking user activity
override
stopTracking() → Future<bool>
Stops tracking user activity
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited