CustomActivityRecognitionPlatform class abstract

The interface that implementations of custom_activity_recognition must implement.

Inheritance
  • Object
  • PlatformInterface
  • CustomActivityRecognitionPlatform
Implementers

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

activityStream() → Stream<ActivityData>
Stream of activity data
checkPermissionStatus() → Future<CustomActivityPermissionStatus>
Checks the current status of activity recognition permission
isActivityRecognitionAvailable() → Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
requestPermissions() → Future<bool>
Requests permissions for activity recognition
startTracking({bool showNotification = true, bool useTransitionRecognition = true, bool useActivityRecognition = true, int detectionIntervalMillis = 10000, int confidenceThreshold = 50}) → Future<bool>
Starts tracking user activity
stopTracking() → Future<bool>
Stops tracking user activity
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ CustomActivityRecognitionPlatform
The default instance of CustomActivityRecognitionPlatform to use.
getter/setter pair